# dispy: Node Information

IP Address |
Name |
Available CPUs |
CPUs Managed by dispy |
Available CPU | Unknown
Available Memory | Unknown
Available Disk Space | Unknown
Jobs Done |
CPU Time Used Sec |
CPU Time Sec / Job |
Last Update |

Jobs Running
Select | Cluster | Job ID | Arguments | Scheduled Time
--- | --- | --- | --- | ---

Terminate Selected Jobs :

Update Interval Seconds:
Name or IP of Node to Show :